@@ -1,5 +1,4 @@
 from datetime import datetime
-from re import template
 from RupineHeroku.rupine_db import herokuDbAccess
 from psycopg2 import sql
 import json
@@ -16,7 +15,7 @@ def POST(connection, schema, tableName:str, data:dict, onConflict:bool=False, un
 
     params = []
     for key in data:
-        if type(data[key]) == dict:
+        if type(data[key]) == dict or type(data[key]) == list:
             params.append(json.dumps(data[key]))
         else:
             params.append(data[key])
@@ -34,11 +33,12 @@ def POST_BULK(connection, schema, tableName:str, data:list, byCopy = True, onCon
     columns = []
     template = []
     for row in res:
-        columns.append(row[0])
-        if row[1] == 'json':
-            template.append('%s::json')
-        else:
-            template.append('%s')
+        if row[0] in data[0]:
+            columns.append(row[0])
+            if row[1] == 'json':
+                template.append('%s::json')
+            else:
+                template.append('%s')
     template = '(' + ','.join(template) + ')' 
 
     newData = []
@@ -49,8 +49,16 @@ def POST_BULK(connection, schema, tableName:str, data:list, byCopy = True, onCon
         newItem = []
         for column in columns:
             if column in item:
-                if type(item[column]) == dict:
-                    newItem.append(json.dumps(item[column]))
+                if type(item[column]) == dict or type(item[column]) == list:
+                    if byCopy:
+                        newItem.append(json.dumps(item[column]).encode('utf8'))
+                    else:
+                        newItem.append(json.dumps(item[column]))
+                elif type(item[column]) == str:
+                    if byCopy:
+                        newItem.append(str(item[column]).encode('utf8'))
+                    else:
+                        newItem.append(item[column])
                 else:
                     newItem.append(item[column])
             else:
@@ -77,7 +85,7 @@ def PUT(connection, schema, updates:dict, tableName:str, conditions:dict={}):
     params = []
     for key in updates.keys():
         setArray.append(sqlTemplateEqual.format(key))
-        if type(updates[key]) == dict:
+        if type(updates[key]) == dict or type(updates[key]) == list:
             params.append(json.dumps(updates[key]))
             
         else:
@@ -120,8 +128,10 @@ def PUT_BULK(connection, schema, updates:list, tableName:str, conditionColumns:l
         newItem = []
         for column in columns:
             if column in item:
-                if type(item[column]) == dict:
-                    newItem.append(json.dumps(item[column]))
+                if type(item[column]) == dict or type(item[column]) == list:
+                    newItem.append(json.dumps(item[column]).encode('utf8'))
+                elif type(item[column]) == str:
+                    newItem.append(str(item[column]).encode('utf8'))
                 else:
                     newItem.append(item[column])
             else:
@@ -221,12 +231,13 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
         result.append(resultDict)
     return result
 
-import os
-from dotenv import load_dotenv
-import herokuDbAccess as db
-import time
+# import os
+# from dotenv import load_dotenv
+# import herokuDbAccess as db
+# import time
+# import decimal
 
-load_dotenv()
+# load_dotenv()
 
 # def convertToType(data,type):
 #     if data is None:
@@ -253,49 +264,92 @@ load_dotenv()
 #         'lp_pool_tokens':convertToType(res[15],float),
 #     }
 
-if __name__ == '__main__':
-    connection = db.connect(
-        os.environ.get("HEROKU_GOD_USER"),
-        os.environ.get("HEROKU_GOD_PASSWORD"),
-        os.environ.get("HEROKU_HOST"),
-        os.environ.get("HEROKU_PORT"),
-        os.environ.get("HEROKU_DB")
-    )
+# if __name__ == '__main__':
+#     connection = db.connect(
+#         os.environ.get("HEROKU_GOD_USER"),
+#         os.environ.get("HEROKU_GOD_PASSWORD"),
+#         os.environ.get("HEROKU_HOST"),
+#         os.environ.get("HEROKU_PORT"),
+#         os.environ.get("HEROKU_DB")
+#     )
 
-    start = time.time()
+#     r = POST_BULK(connection,'dbdev','testbulk',[{'number':2}],True)
+#     print(r)
+    #r = POST_BULK(connection,'dbdev','testbulk',[{'id':1,'t':'TSLA'}],True)
+    #r = POST_BULK(connection,'dbdev','testbulk',[{'id':1,'t':'TSLA/v1'}],True)
+    # d = {
+    #     'id': '19488fdb3c264e181117ba8f764f486df43c1a25a29f5bef74f123a1eb665e13_6_-1_0_ARKK', 
+    #     'txid': '19488fdb3c264e181117ba8f764f486df43c1a25a29f5bef74f123a1eb665e13', 
+    #     'public_address': 'dRPF64SSDi5h9hpTx3KRWX5U86MByES34s', 
+    #     'transaction_type': 'removepoolliquidity', 
+    #     'block_number': 1610004, 
+    #     'block_timestamp': 1644358131, 
+    #     'tx_order': 6, 
+    #     'vin': None, 
+    #     'vout': 0, 
+    #     'token_in': 'ARKK-DUSD', 
+    #     'amount_in': 1343094801, 
+    #     'share_address': 'dRPF64SSDi5h9hpTx3KRWX5U86MByES34s', 
+    #     'token_out': 'ARKK', 
+    #     'poolsymbols_route': None, 
+    #     'max_price':decimal.Decimal(1000000000000002.00000000),
+    #     'amount_out':135528499,
+    #     'has_listaccounthistory_correction':'Y'
+    # }
+    # d = {
+    #     'id': 'f',
+    #     'txid': 't', 
+    #     'public_address': 't', 
+    #     'transaction_type': 't', 
+    #     'block_number': 1, 
+    #     'block_timestamp': 1, 
+    #     'tx_order': 3, 
+    #     'token_in': 't', 
+    #     'share_address': 't',
+    #     'max_price': decimal.Decimal(1000000000000002.00000000),
+    #     'poolsymbols_route': {'here': 1, 'is': {'a': ['deep','json']}},
+    #     'has_listaccounthistory_correction':'Y'}
+    # r = POST_BULK(connection,'dbdev','testbulk',[d],False,True)
+    # print(r)
+    # r = PUT_BULK(connection,'dbdev',[{
+    #     'id': 1,
+    #     'number':decimal.Decimal('1000000000000000.00000000')
+    # }],'testbulk')
+    # print(r)
+#     start = time.time()
     
-    for i in range(10,20):
-        data = {
-            'id': i,
-            'number':i+20
-        }
-        updates = {
-            'number':i+200
-        }
-        conditions = {
-            'id': i
-        }
-        #r= POST(connection,'dbdev','testbulk',data,True,'id')
-        r = PUT(connection,'dbdev',updates,'testbulk',conditions)
-        print(r)
+#     for i in range(10,20):
+#         data = {
+#             'id': i,
+#             'number':i+20
+#         }
+#         updates = {
+#             'number':i+200
+#         }
+#         conditions = {
+#             'id': i
+#         }
+#         #r= POST(connection,'dbdev','testbulk',data,True,'id')
+#         r = PUT(connection,'dbdev',updates,'testbulk',conditions)
+#         print(r)
 
-    end = time.time()
-    print(end - start)
+#     end = time.time()
+#     print(end - start)
 
-    start = time.time()
-    data = []
-    for i in range(1,10):
-        item = {
-            'id': i,
-            'number':i+200
-        }
-        data.append(item)
-    #r = POST_BULK(connection,'dbdev','testbulk',data,False,True,'id')
-    r = PUT_BULK(connection,'dbdev',data,'testbulk')
-    print(r)
+#     start = time.time()
+#     data = []
+#     for i in range(1,10):
+#         item = {
+#             'id': i,
+#             'number':i+200
+#         }
+#         data.append(item)
+#     #r = POST_BULK(connection,'dbdev','testbulk',data,False,True,'id')
+#     r = PUT_BULK(connection,'dbdev',data,'testbulk')
+#     print(r)
 
-    end = time.time()
-    print(end - start)
+#     end = time.time()
+#     print(end - start)
 
     
 
