@@ -13,7 +13,8 @@ class ObjDmhNetwork:
     github_org = ''
     telegram_link = ''
     created_at = 0 
-    modified_at= 0
+    modified_at = 0
+    network_no = 0
 
 def ParseDataIntoObj(data):
     retObj = ObjDmhNetwork()
@@ -29,12 +30,13 @@ def ParseDataIntoObj(data):
     retObj.telegram_link = data[9]
     retObj.created_at = data[10]
     retObj.modified_at= data[11]
+    retObj.network_no= data[12]
     return retObj
 
 def getNetworkList(connection, schema):
     
     # query database    
-    query = sql.SQL("SELECT gecko_id, gecko_name, gecko_symbol, cmc_id, chain_id, twitter_name, twitter_id, twitter_hashtag, github_org, telegram_link, created_at, modified_at \
+    query = sql.SQL("SELECT gecko_id, gecko_name, gecko_symbol, cmc_id, chain_id, twitter_name, twitter_id, twitter_hashtag, github_org, telegram_link, created_at, modified_at, network_no \
         FROM {}.dwh_network").format(sql.Identifier(schema))
     result = herokuDbAccess.fetchDataInDatabase(query, [], connection)    
     
